@@ -104,7 +104,7 @@ $this->css()
 						if (!$this->question->get('anonymous'))
 						{
 							$name = $this->escape(stripslashes($this->question->creator->get('name', Lang::txt('COM_ANSWERS_UNKNOWN'))));
-							if (in_array($this->question->creator->get('access'), User::getAuthorisedViewLevels()))
+							if (in_array($this->question->creator->get('access'), User::getAuthorisedViewLevels()) && !$this->question->creator->get('block') && $this->question->creator->get('approved'))
 							{
 								$name = '<a href="' . Route::url($this->question->creator->link()) . '">' . $name . '</a>';
 							}
