@@ -128,9 +128,8 @@ class Repo extends Object
 			// Use regex to avoid what might be a caching thing with JTables
 			$matches = array();
 			preg_match('/versionTracking=(\d)/', $this->get('project')->get('params'), $matches);
-			// Assume if versionTracking param was not set that it was tracked via git previously
-			// Otherwise honor the variable
-			if (!isset($matches[1]) || $matches[1] == 1)
+			// Only use git adapter if project specifies it - otherwise assume we're not using git
+			if (isset($matches[1]) && $matches[1] == 1)
 			{
 				$engine = 'git';
 			}
@@ -181,9 +180,8 @@ class Repo extends Object
 				// Use regex to avoid what might be a caching thing with JTables
 				$matches = array();
 				preg_match('/versionTracking=(\d)/', $this->get('project')->get('params'), $matches);
-				// Assume if versionTracking param was not set that it was tracked via git previously
-				// Otherwise honor the variable
-				if (!isset($matches[1]) || $matches[1] == 1)
+				// Only use git adapter if project specifies it - otherwise assume we're not using git
+				if (isset($matches[1]) && $matches[1] == 1)
 				{
 					$engine = 'git';
 				}
@@ -211,6 +209,18 @@ class Repo extends Object
 		return $this->_adapter;
 	}
 
+	public function getAdapterName()
+	{
+		if (!$this->_adapter)
+		{
+			$this->_adapter();
+		}
+		$class = get_class($this->_adapter);
+		$lastSlash = strrpos($class, '\\');
+		$className = substr($class, $lastSlash + 1);
+		return strtolower($className);
+	}
+
 	/**
 	 * Check that repo exists and connection established
 	 *
@@ -1518,13 +1528,12 @@ class Repo extends Object
 			$base_path = DS . trim($pubconfig->get('webpath'), DS);
 
 			chdir(PATH_APP . $base_path);
-			exec('du -sk ', $out);
+			exec('du -sb ', $out);
 			$used = 0;
 
 			if ($out && isset($out[0]))
 			{
-				$kb = str_replace('.', '', trim($out[0]));
-				$used = $kb * 1024;
+				$used = str_replace('.', '', trim($out[0]));
 			}
 
 			return $used;
@@ -1553,7 +1562,11 @@ class Repo extends Object
 			}
 			else
 			{
-				$engine = $this->get('project')->params->get('engine');
+				$engine = 'nogit';
+				if ($this->get('project'))
+				{
+					$engine = $this->get('project')->params->get('engine', 'nogit');
+				}
 				if ($engine == 'git')
 				{
 					$git = new Helpers\Git($path);
@@ -1582,11 +1595,15 @@ class Repo extends Object
 				}
 				else
 				{
+					$commits = 0; // There are no commits in nogit, stub for reports
 					$helper = new Helpers\Nogit($path);
-					$count = count($helper->getFiles());
+					$recursive = true;
+					$subdir = '';
+					$count = count($helper->getFiles($subdir, $recursive));
+					$files = $files + $count; // Count the files in a project and add to total for a report
 					if ($count > 1)
 					{
-						$usage++;
+						$usage++; // A project is using files, increment for reports
 					}
 				}
 			}
