@@ -333,10 +333,6 @@ class Tickets extends AdminController
 		$this->view->filters = Utilities::getFilters();
 		$this->view->lists = array();
 
-		// Get resolutions
-		$sr = new Tables\Resolution($this->database);
-		$this->view->lists['resolutions'] = $sr->getResolutions();
-
 		// Get messages
 		$sm = new Tables\Message($this->database);
 		$this->view->lists['messages'] = $sm->getMessages();
@@ -921,10 +917,6 @@ class Tickets extends AdminController
 		$this->view->filters = Utilities::getFilters();
 		$this->view->lists = array();
 
-		// Get resolutions
-		$sr = new Tables\Resolution($this->database);
-		$this->view->lists['resolutions'] = $sr->getResolutions();
-
 		// Get categories
 		$sa = new Tables\Category($this->database);
 		$this->view->lists['categories'] = $sa->find('list');
