@@ -42,13 +42,17 @@ use Config;
 use Route;
 use Lang;
 
-require_once(dirname(dirname(__DIR__)) . DS . 'models' . DS . 'ticket.php');
-require_once(dirname(dirname(__DIR__)) . DS . 'helpers' . DS . 'acl.php');
+require_once(dirname(dirname(__DIR__)) . '/models/orm/comment.php');
+require_once(dirname(dirname(__DIR__)) . '/models/orm/ticket.php');
+require_once(dirname(dirname(__DIR__)) . '/models/orm/status.php');
+require_once(dirname(dirname(__DIR__)) . '/models/orm/attachment.php');
+require_once(dirname(dirname(__DIR__)) . '/helpers/acl.php');
+require_once(dirname(dirname(__DIR__)) . '/helpers/utilities.php');
 
 /**
  * API controller class for support tickets
  */
-class Commentsv1_0 extends ApiController
+class Commentsv2_0 extends ApiController
 {
 	/**
 	 * Execute a request
@@ -61,7 +65,7 @@ class Commentsv1_0 extends ApiController
 		$this->database = \App::get('db');
 
 		$this->acl = \Components\Support\Helpers\ACL::getACL();
-		$this->acl->setUser($userid);
+		$this->acl->setUser(User::get('id'));
 
 		parent::execute();
 	}
@@ -70,43 +74,20 @@ class Commentsv1_0 extends ApiController
 	 * Display comments for a ticket
 	 *
 	 * @apiMethod GET
-	 * @apiUri    /support/{ticket}/comments/list
+	 * @apiUri    /support/comments
 	 * @apiParameter {
-	 * 		"name":          "limit",
-	 * 		"description":   "Number of result to return.",
+	 * 		"name":          "ticket",
+	 * 		"description":   "List comments from a specific ticket (by id)",
 	 * 		"type":          "integer",
 	 * 		"required":      false,
-	 * 		"default":       25
+	 * 		"default":       null,
 	 * }
 	 * @apiParameter {
-	 * 		"name":          "limitstart",
-	 * 		"description":   "Number of where to start returning results.",
+	 * 		"name":          "created_by",
+	 * 		"description":   "List comments from a specific user (by id)",
 	 * 		"type":          "integer",
 	 * 		"required":      false,
-	 * 		"default":       0
-	 * }
-	 * @apiParameter {
-	 * 		"name":          "search",
-	 * 		"description":   "A word or phrase to search for.",
-	 * 		"type":          "string",
-	 * 		"required":      false,
-	 * 		"default":       ""
-	 * }
-	 * @apiParameter {
-	 * 		"name":          "sort",
-	 * 		"description":   "Field to sort results by.",
-	 * 		"type":          "string",
-	 * 		"required":      false,
-	 *      "default":       "created",
-	 * 		"allowedValues": "created, id, state"
-	 * }
-	 * @apiParameter {
-	 * 		"name":          "sort_Dir",
-	 * 		"description":   "Direction to sort results by.",
-	 * 		"type":          "string",
-	 * 		"required":      false,
-	 * 		"default":       "desc",
-	 * 		"allowedValues": "asc, desc"
+	 * 		"default":       null,
 	 * }
 	 * @return    void
 	 */
@@ -119,89 +100,33 @@ class Commentsv1_0 extends ApiController
 			throw new Exception(Lang::txt('Not authorized'), 403);
 		}
 
-		$obj = new \Components\Support\Tables\Ticket($this->database);
+		$comments = \Components\Support\Models\Orm\Comment::all();
 
-		$filters = array(
-			'limit'      => Request::getInt('limit', 25),
-			'start'      => Request::getInt('limitstart', 0),
-			'search'     => Request::getVar('search', ''),
-			'sort'       => Request::getWord('sort', 'created'),
-			'sortdir'    => strtoupper(Request::getWord('sort_Dir', 'DESC')),
-			'group'      => Request::getVar('group', ''),
-			'reportedby' => Request::getVar('reporter', ''),
-			'owner'      => Request::getVar('owner', ''),
-			'type'       => Request::getInt('type', 0),
-			'status'     => strtolower(Request::getWord('status', '')),
-			'tag'        => Request::getWord('tag', ''),
-		);
-
-		$filters['opened'] = $this->_toTimestamp(Request::getVar('opened', ''));
-		$filters['closed'] = $this->_toTimestamp(Request::getVar('closed', ''));
+		if (Request::getInt('ticket', null))
+		{
+			$comments = $comments->whereEquals('ticket', Request::get('ticket'));
+		}
+		if (Request::getInt('created_by', null))
+		{
+			$comments = $comments->whereEquals('created_by', Request::get('created_by'));
+		}
 
 		$response = new stdClass;
-		$response->success = true;
-		$response->total   = 0;
-		$response->tickets = array();
-
-		// Get a list of all statuses
-		$sobj = new \Components\Support\Tables\Status($this->database);
-
-		$statuses = array();
-		if ($data = $sobj->find('all'))
+		$response->total = $comments->count();
+		$response->comments = array();
+		foreach ($comments->rows() as $row)
 		{
-			foreach ($data as $status)
-			{
-				$statuses[$status->id] = $status;
-			}
+			$temp = array();
+			$changelog = json_decode($row->changelog);
+			$temp['id'] = $row->id;
+			$temp['comment'] = $row->comment;
+			$temp['created'] = $row->created;
+			$temp['created_by'] = $row->created_by;
+			$temp['changelog'] = $changelog;
+			$temp['private'] = $row->access;
+
+			$response->comments[] = $temp;
 		}
-
-		// Get a count of tickets
-		$response->total = $obj->getTicketsCount($filters);
-
-		if ($response->total)
-		{
-			$response->tickets = $obj->getTickets($filters);
-
-			foreach ($response->tickets as $i => $ticket)
-			{
-				$owner = $ticket->owner;
-
-				$response->tickets[$i]->owner = new stdClass;
-				$response->tickets[$i]->owner->username = $owner;
-				$response->tickets[$i]->owner->name     = $ticket->owner_name;
-				$response->tickets[$i]->owner->id       = $ticket->owner_id;
-
-				unset($response->tickets[$i]->owner_name);
-				unset($response->tickets[$i]->owner_id);
-
-				$response->tickets[$i]->reporter = new stdClass;
-				$response->tickets[$i]->reporter->name     = $ticket->name;
-				$response->tickets[$i]->reporter->username = $ticket->login;
-				$response->tickets[$i]->reporter->email    = $ticket->email;
-
-				unset($response->tickets[$i]->name);
-				unset($response->tickets[$i]->login);
-				unset($response->tickets[$i]->email);
-
-				$status = $response->tickets[$i]->status;
-
-				$response->tickets[$i]->status = new stdClass;
-				if (!$status)
-				{
-					$response->tickets[$i]->status->alias = 'new';
-					$response->tickets[$i]->status->title = 'New';
-				}
-				else
-				{
-					$response->tickets[$i]->status->alias = (isset($statuses[$status]) ? $statuses[$status]->alias : 'unknown');
-					$response->tickets[$i]->status->title = (isset($statuses[$status]) ? $statuses[$status]->title : 'unknown');
-				}
-				$response->tickets[$i]->status->id    = $status;
-
-				$response->tickets[$i]->url = str_replace('/api', '', rtrim(Request::base(), '/') . '/' . ltrim(Route::url('index.php?option=com_support&controller=tickets&task=tickets&id=' . $response->tickets[$i]->id), '/'));
-			}
-		}
-
 		$this->send($response);
 	}
 
@@ -209,34 +134,84 @@ class Commentsv1_0 extends ApiController
 	 * Create a new comment
 	 *
 	 * @apiMethod POST
-	 * @apiUri    /support/{ticket}/comments
+	 * @apiUri    /support/comments
 	 * @apiParameter {
-	 * 		"name":        "scope",
-	 * 		"description": "Scope type (group, member, etc.)",
-	 * 		"type":        "string",
-	 * 		"required":    true,
-	 * 		"default":     null
-	 * }
-	 * @apiParameter {
-	 * 		"name":        "scope_id",
-	 * 		"description": "Scope object ID",
+	 * 		"name":        "ticket",
+	 * 		"description": "Id of the ticket to make a comment on",
 	 * 		"type":        "integer",
 	 * 		"required":    true,
-	 * 		"default":     null
+	 * 		"default":		 null
 	 * }
 	 * @apiParameter {
-	 * 		"name":        "title",
-	 * 		"description": "Entry title",
+	 * 		"name":        "comment",
+	 * 		"description": "Comment text",
 	 * 		"type":        "string",
 	 * 		"required":    true,
-	 * 		"default":     null
+	 * 		"default":		 null
 	 * }
 	 * @apiParameter {
-	 * 		"name":        "alias",
-	 * 		"description": "Entry alias",
+	 * 		"name":        "group",
+	 * 		"description": "Group to assign the ticket to (by alias)",
 	 * 		"type":        "string",
 	 * 		"required":    false,
-	 * 		"default":     null
+	 * 		"default":		 null
+	 * }
+	 * @apiParameter {
+	 * 		"name":        "owner",
+	 * 		"description": "Id of the owner to assign ticket to",
+	 * 		"type":        "integer",
+	 * 		"required":    false,
+	 * 		"default":		 null
+	 * }
+	 * @apiParameter {
+	 * 		"name":        "severity",
+	 * 		"description": "Severity of the ticket",
+	 * 		"type":        "string",
+	 * 		"required":    false,
+	 * 		"default":		 null
+	 *		"allowed_values":	"minor, normal, major, critical"
+	 * }
+	 * @apiParameter {
+	 * 		"name":        "status",
+	 * 		"description": "Status of the ticket",
+	 * 		"type":        "integer",
+	 * 		"required":    false,
+	 * 		"default":		 null
+	 * }
+	 * @apiParameter {
+	 * 		"name":        "target_date",
+	 * 		"description": "Target date for completion of ticket (YYYY-MM-DD hh:mm:ss)",
+	 * 		"type":        "string",
+	 * 		"required":    false,
+	 * 		"default":		 null
+	 * }
+	 * @apiParameter {
+	 * 		"name":        "cc",
+	 * 		"description": "Comma seperated list of email addresses to email updates to",
+	 * 		"type":        "string",
+	 * 		"required":    false,
+	 * 		"default":		 submitter,owner
+	 * }
+	 * @apiParameter {
+	 * 		"name":        "private",
+	 * 		"description": "Should the comment be flagged as private",
+	 * 		"type":        "boolean",
+	 * 		"required":    false,
+	 * 		"default":		 false
+	 * }
+	 * @apiParameter {
+	 * 		"name":        "email_submitter",
+	 * 		"description": "Should the submitter be emailed about this comment",
+	 * 		"type":        "boolean",
+	 * 		"required":    false,
+	 * 		"default":		 false
+	 * }
+	 * @apiParameter {
+	 * 		"name":        "email_owner",
+	 * 		"description": "Should the ticket owner be emailed about this comment",
+	 * 		"type":        "boolean",
+	 * 		"required":    false,
+	 * 		"default":		 false
 	 * }
 	 * @return     void
 	 */
@@ -249,90 +224,138 @@ class Commentsv1_0 extends ApiController
 			throw new Exception(Lang::txt('Not authorized'), 403);
 		}
 
-		$ticket_id = Request::getInt('ticket', 0, 'post');
-
-		// Load the old ticket so we can compare for the changelog
-		$old = new \Components\Support\Models\Ticket($ticket_id);
-		$old->set('tags', $old->tags('string'));
-
-		if (!$old->exists())
+		$ticket_id = Request::getInt('ticket', null);
+		if (!isset($ticket_id))
 		{
-			$this->errorMessage(500, Lang::txt('Ticket "%s" does not exist.', $ticket_id));
-			return;
+			throw new Exception(Lang::txt('Bad request - ticket ID required'), 400);
 		}
 
-		// Initiate class and bind posted items to database fields
-		$ticket = new \Components\Support\Models\Ticket($ticket_id);
-		$ticket->set('status',   Request::getInt('status', $ticket->get('status'), 'post'));
-		$ticket->set('open',     Request::getInt('open', $ticket->get('open'), 'post'));
-		$ticket->set('category', Request::getInt('category', $ticket->get('category'), 'post'));
-		$ticket->set('severity', Request::getVar('severity', $ticket->get('severity'), 'post'));
-		$ticket->set('owner',    Request::getVar('owner', $ticket->get('owner'), 'post'));
-		$ticket->set('group',    Request::getVar('group', $ticket->get('group'), 'post'));
-
-		// If an existing ticket AND closed AND previously open
-		if ($ticket_id && !$ticket->get('open') && $ticket->get('open') != $old->get('open'))
+		$comment_text = Request::getString('comment', '');
+		if ($comment_text == '')
 		{
-			// Record the closing time
-			$ticket->set('closed', Date::toSql());
+			throw new Exception(Lang::txt('Bad request - comment required'), 400);
 		}
 
-		// Any tags?
-		if ($tags = trim(Request::getVar('tags', '', 'post')))
+		$ticket = \Components\Support\Models\Orm\Ticket::oneOrFail($ticket_id);
+		$comment = new \Components\Support\Models\Orm\Comment();
+		$changelog = new stdClass;
+
+		$comment->set('ticket', Request::get('ticket', ''));
+		$comment->set('comment', nl2br(Request::get('comment')));
+		$comment->set('created_by', User::get('id'));
+		$comment->set('access', (Request::get('private', false) == 'true' ? 1 : 0));
+
+		$changes = array();
+		foreach (['group_id', 'owner', 'severity', 'status', 'target_date', 'category'] as $index)
 		{
-			$ticket->tag($tags, $user->get('uidNumber'));
-			$ticket->set('tags', $ticket->tags('string'));
+			if (Request::get($index, null))
+			{
+				if (Request::get($index) != $ticket->get($index))
+				{
+					$temp = new stdClass;
+					$temp->field = $index;
+					$temp->before = $ticket->get($index);
+					$temp->after = Request::get($index);
+					if ($index == 'status')
+					{
+						if ($ticket->get('status') == 0)
+						{
+							$status_model = new \Components\Support\Models\Orm\Status();
+							$status_model->set('title', 'Closed');
+							$status_model->set('open', 0);
+						}
+						else
+						{
+							$status_model = \Components\Support\Models\Orm\Status::oneOrFail(Request::get('status'));
+						}
+						if ($ticket->get('status') == 0)
+						{
+							$old_status = new \Components\Support\Models\Orm\Status();
+							$old_status->set('title', 'Closed');
+							$old_status->set('open', 0);
+						}
+						else
+						{
+							$old_status = \Components\Support\Models\Orm\Status::oneOrFail($ticket->get('status'));
+						}
+						$temp->before = $old_status->get('title');
+						$temp->after = $status_model->get('title');
+						$ticket->set('open', $status_model->get('open'));
+						if ($status_model->get('get') == 'open' && $ticket->get('status', null) == 'closed')
+						{
+							$tiket->set('closed', '0000-00-00 00:00:00');
+						}
+						if ($status_model->get('get') == 'closed' && $ticket->get('status', null) == 'open')
+						{
+							$ticket->set('closed', Date::toSql());
+						}
+					}
+					if ($index == 'owner')
+					{
+						$old_owner = User::getInstance($ticket->get('owner'));
+						$new_owner = User::getInstance(Request::get('owner'));
+						$temp->before = $old_owner->get('username');
+						$temp->after = $new_owner->get('username');
+					}
+					$ticket->set($index, Request::get($index));
+					$changes[] = $temp;
+				}
+			}
 		}
 
-		// Store new content
-		if (!$ticket->store())
-		{
-			$this->errorMessage(500, $ticket->getError());
-			return;
-		}
+		$changelog->changes = $changes;
 
-		// Create a new comment
-		$comment = new \Components\Support\Models\Comment();
-		$comment->set('ticket', $ticket->get('id'));
-		$comment->set('comment', nl2br(Request::getVar('comment', '', 'post', 'none', 2)));
 		if ($comment->get('comment'))
 		{
 			// If a comment was posted by the ticket submitter to a "waiting user response" ticket, change status.
-			if ($ticket->isWaiting() && $user->get('username') == $ticket->get('login'))
+			$user = User::getInstance(User::get('id'));
+			if ($ticket->get('status') == 2 && $user->get('username') == $ticket->get('login'))
 			{
-				$ticket->open();
+				$ticket->set('status', 0);
 			}
 		}
-		$comment->set('created', Date::toSql());
-		$comment->set('created_by', $user->get('uidNumber'));
-		$comment->set('access', Request::getInt('access', 0, 'post'));
 
-		// Compare fields to find out what has changed for this ticket and build a changelog
-		$comment->changelog()->diff($old, $ticket);
-
-		$comment->changelog()->cced(Request::getVar('cc', '', 'post'));
-
-		// Store new content
-		if (!$comment->store())
+		$comment->set('changelog', json_encode($changelog));
+		if (!$comment->save())
 		{
-			$this->errorMessage(500, $comment->getError());
-			return;
+			throw new Exception(print_r($comment->getErrors(), 1), 500);
+		}
+		if (!$ticket->save())
+		{
+			throw new Exception(print_r($ticket->getErrors(), 1), 500);
 		}
 
-		if ($ticket->get('owner'))
+		// There's now a ticket and a comment, lets add attachments
+		\Components\Support\Helpers\Utilities::addAttachments($ticket->get('id'), $comment->get('id'));
+
+		$msg = new stdClass;
+		$msg->id  = $comment->get('id');
+		$msg->notified = $comment->get('changelog');
+
+		$this->send($msg, 200, 'OK');
+/*
+		$changlog->notifications = array();
+		if (Request::get('email_owner'))
 		{
 			$comment->addTo(array(
 				'role'  => Lang::txt('COM_SUPPORT_COMMENT_SEND_EMAIL_OWNER'),
-				'name'  => $ticket->owner('name'),
-				'email' => $ticket->owner('email'),
-				'id'    => $ticket->owner('id')
+				'name'  => $ticket->get_owner->get('name'),
+				'email' => $ticket->get_owner->get('email'),
+				'id'    => $ticket->get_owner->get('id')
 			));
+			$changelog->notifications[] = json_encode(array('role'=>'Ticket owner', 'address'=>$ticket->get_owner()->get('email'), 'name'=>$ticket->get_owner()->get('name')));
 		}
 
 		// Add any CCs to the e-mail list
-		foreach ($comment->changelog()->get('cc') as $cc)
+		$cc = Request::get('cc', null);
+		if ($cc)
 		{
-			$comment->addTo($cc, Lang::txt('COM_SUPPORT_COMMENT_SEND_EMAIL_CC'));
+			$cc = explode(',', $cc);
+			foreach ($cc)
+			{
+				$comment->addTo($cc, Lang::txt('COM_SUPPORT_COMMENT_SEND_EMAIL_CC'));
+			}
+			$changelog->cc = json_encode($cc);
 		}
 
 		// Check if the notify list has eny entries
@@ -431,43 +454,25 @@ class Commentsv1_0 extends ApiController
 				);
 			}
 		}
-
-		// Were there any changes?
-		if (count($comment->changelog()->get('notifications')) > 0
-		 || count($comment->changelog()->get('cc')) > 0
-		 || count($comment->changelog()->get('changes')) > 0)
-		{
-			// Save the data
-			if (!$comment->store())
-			{
-				$this->errorMessage(500, $comment->getError());
-				return;
-			}
-		}
+		$comment->set('changelog', json_encode($changelog));
+		$comment->save();
+		$ticket->save();
 
 		$msg = new stdClass;
-		$msg->ticket   = $ticket->get('id');
-		$msg->comment  = $comment->get('id');
-		$msg->notified = $comment->changelog()->get('notifications');
+		$msg->id  = $comment->get('id');
+		$msg->notified = $comment->get('changelog');
 
-		$this->setMessageType(Request::getVar('format', 'json'));
 		$this->send($msg, 200, 'OK');
+*/
 	}
 
 	/**
 	 * Displays details for a ticket comment
 	 *
 	 * @apiMethod GET
-	 * @apiUri    /support/{ticket}/comments/{comment}
+	 * @apiUri    /support/comments/{id}
 	 * @apiParameter {
-	 * 		"name":        "ticket",
-	 * 		"description": "Ticket identifier",
-	 * 		"type":        "integer",
-	 * 		"required":    true,
-	 * 		"default":     0
-	 * }
-	 * @apiParameter {
-	 * 		"name":        "comment",
+	 * 		"name":        "id",
 	 * 		"description": "Comment identifier",
 	 * 		"type":        "integer",
 	 * 		"required":    true,
@@ -485,24 +490,25 @@ class Commentsv1_0 extends ApiController
 		}
 
 		// Initiate class and bind data to database fields
-		$id = Request::getInt('comment', 0);
+		$id = Request::getInt('id', 0);
 
 		// Initiate class and bind data to database fields
-		$ticket = new \Components\Support\Models\Comment($id);
+		$comment = \Components\Support\Models\Orm\Comment::oneOrFail($id);
 
 		$response = new stdClass;
 		$response->id = $comment->get('id');
 		$response->ticket = $comment->get('ticket');
+		$response->comment = $comment->get('comment');
+		$response->created = $comment->get('created');
 
-		$response->owner = new stdClass;
-		$response->owner->username = $ticket->owner('username');
-		$response->owner->name     = $ticket->owner('name');
-		$response->owner->id       = $ticket->owner('id');
-
-		$response->content = $comment->content('raw');
-
-		$response->url = str_replace('/api', '', rtrim(Request::base(), '/') . '/' . ltrim(Route::url('index.php?option=com_support&controller=tickets&task=tickets&id=' . $comment->get('ticket') . '#c' . $comment->get('id')), '/'));
+		$creator = $comment->creator;
+		$response->created_by = new stdClass;
+		$response->created_by->username = $creator->get('username');
+		$response->created_by->name     = $creator->get('name');
+		$response->created_by->id       = $creator->get('id');
+		$response->created_by->email    = $creator->get('email');
 
+		$response->changelog = $comment->get('changelog');
 		$response->private = ($comment->get('access') ? true : false);
 
 		$this->send($response);
@@ -512,14 +518,7 @@ class Commentsv1_0 extends ApiController
 	 * Update a ticket comment
 	 *
 	 * @apiMethod PUT
-	 * @apiUri    /support/{ticket}/comments/{comment}
-	 * @apiParameter {
-	 * 		"name":        "ticket",
-	 * 		"description": "Ticket identifier",
-	 * 		"type":        "integer",
-	 * 		"required":    true,
-	 * 		"default":     0
-	 * }
+	 * @apiUri    /support/comments/{id}
 	 * @apiParameter {
 	 * 		"name":        "comment",
 	 * 		"description": "Comment identifier",
@@ -538,24 +537,7 @@ class Commentsv1_0 extends ApiController
 			throw new Exception(Lang::txt('Not authorized'), 403);
 		}
 
-		$ticket_id  = Request::getInt('ticket', 0);
-		$comment_id = Request::getInt('comment', 0);
-
-		$ticket = new \Components\Support\Models\Ticket($ticket_id);
-
-		if (!$ticket->exists())
-		{
-			throw new Exception(Lang::txt('COM_SUPPORT_ERROR_MISSING_RECORD'), 404);
-		}
-
-		$comment = new \Components\Support\Models\Comment($comment_id);
-
-		if (!$comment->exists())
-		{
-			throw new Exception(Lang::txt('COM_SUPPORT_ERROR_MISSING_RECORD'), 404);
-		}
-
-		$this->send(null, 204);
+		throw new Exception(Lang::txt('Operation not supported'), 404);
 	}
 
 	/**
@@ -588,33 +570,6 @@ class Commentsv1_0 extends ApiController
 			throw new Exception(Lang::txt('Not authorized'), 403);
 		}
 
-		$ticket_id  = Request::getInt('ticket', 0);
-		$comment_id = Request::getInt('comment', 0);
-
-		$ticket = new \Components\Support\Models\Ticket($ticket_id);
-
-		if (!$ticket->exists())
-		{
-			throw new Exception(Lang::txt('COM_SUPPORT_ERROR_MISSING_RECORD'), 404);
-		}
-
-		$comment = new \Components\Support\Models\Comment($comment_id);
-
-		if (!$comment->exists())
-		{
-			throw new Exception(Lang::txt('COM_SUPPORT_ERROR_MISSING_RECORD'), 404);
-		}
-
-		if ($comment->isPrivate() && !$this->acl->check('delete', 'private_comments'))
-		{
-			throw new Exception(Lang::txt('COM_SUPPORT_ERROR_UNAUTHORIZED'), 403);
-		}
-
-		if (!$comment->delete())
-		{
-			throw new Exception($comment->getError(), 500);
-		}
-
-		$this->send(null, 204);
+		throw new Exception(Lang::txt('Operation not supported'), 404);
 	}
 }
